==> haskell-tree-diff-0.0.1-42-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tree-diff
version: 0.0.1
id: tree-diff-0.0.1-2EyY6rPL5RD6P1s0r6vb8X
key: tree-diff-0.0.1-2EyY6rPL5RD6P1s0r6vb8X
license: BSD-3-Clause
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg.Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/tree-diff
synopsis: Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:
    .
    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @
    .
    This package works on trees.
    .
    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @
    .
    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.
    .
    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.
    .
    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    {fooBool = [-True, +False, False, +True],
    fooInt = 42,
    fooString = -"old" +"new"}
    @
category: Data
abi: d1edfa2232496718608fb19c54d32dca
exposed: True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.Parser
    Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck Data.TreeDiff.Tree
import-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tree-diff-0.0.1
hs-libraries: HStree-diff-0.0.1-2EyY6rPL5RD6P1s0r6vb8X
depends:
    base-4.11.1.0 aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV
    ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ bytestring-0.10.8.2
    containers-0.5.11.0 generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    MemoTrie-0.6.9-4sfm2nZSl776CmmBrLqWoU parsec-3.1.13.0
    parsers-0.12.9-KfRAa0gf2kp2ncyz33QG4o pretty-1.1.3.6
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl=9d4f369601ee2b22ce73b0afa89e8002
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=69b8ea707aa80039da4ef8d7dea33061
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             MemoTrie-0.6.9-4sfm2nZSl776CmmBrLqWoU=5ca2cface446bd417c8e1b716d4af25d
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             parsers-0.12.9-KfRAa0gf2kp2ncyz33QG4o=41f16e24f9afd1c1fd4d7456899adadb
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=073bf76fdf6ac46f8363958226adfe9d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html: /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tree-diff-0.0.1-43-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tree-diff
version: 0.0.1
id: tree-diff-0.0.1-6v8VicTu776GT6BrzyQ59K
key: tree-diff-0.0.1-6v8VicTu776GT6BrzyQ59K
license: BSD-3-Clause
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg.Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/tree-diff
synopsis: Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:
    .
    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @
    .
    This package works on trees.
    .
    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @
    .
    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.
    .
    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.
    .
    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    {fooBool = [-True, +False, False, +True],
    fooInt = 42,
    fooString = -"old" +"new"}
    @
category: Data
abi: cb46d4a0a4c5a7f5ed35606e8e78f84b
exposed: True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.Parser
    Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck Data.TreeDiff.Tree
import-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tree-diff-0.0.1
hs-libraries: HStree-diff-0.0.1-6v8VicTu776GT6BrzyQ59K
depends:
    base-4.11.1.0 aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ bytestring-0.10.8.2
    containers-0.5.11.0 generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    MemoTrie-0.6.9-GXLwsuhOJCZCdZCZX6oUKB parsec-3.1.13.0
    parsers-0.12.9-HSuiRQJTKA09iCHUp4tatf pretty-1.1.3.6
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=69b8ea707aa80039da4ef8d7dea33061
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             MemoTrie-0.6.9-GXLwsuhOJCZCdZCZX6oUKB=b2b29d390887d369bf1c099dd52e79e6
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             parsers-0.12.9-HSuiRQJTKA09iCHUp4tatf=895f22145eb275fad8c9d5dd303ea874
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=073bf76fdf6ac46f8363958226adfe9d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html: /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
